;Adventure Vison 16-in-1 reset bank v0.1
;---------------------------------------

;June 2013 by Mr.Blinky

;The Adventure Vision nor it's rom socket has a reset feature
;in order to 'reset' a game and return to the menu. the 16-in-1
;bank register is reset by pressing the menu button.

;how it works
;------------

;When the menu button is pressed the bank register is cleared and 
;rom bank 0 is selected. At that moment the 8048 can executes code at a 
;random ROM address or code in the BIOS. Since BIOS is internal the
;8048 continues to execute code untill it returns to ROM.
;When a 8048 fetches a new instruction (or 2nd byte opcode) from ROM
;it will fetch it from rom bank 0.
;Bank zero contains a repeat of some specific instructions that will
;always jump to a switch routine that will jump to the beginning of
;rom bank 1 in which the menu is located.
;since the programm counter wraps to beginning of the selected memory
;bank, there are two switch routines. One to select memory bank 0 and
;one to select rom bank 1

;Banking mechanism:
;------------------

;any access to $F00-$FFF will latch the LSB of the program counter into
;the bank register (74LS373 latch)

;Accesses to $F80-$FFF will lock the register from further changes

.equ	MENU_BANK,	$01

;Reset vector
;------------

	.org $000
	  
	SEL MB0			;switch code located at bank 1
	JMP switch

;External interrupt vector
;-------------------------

;note:
;Adventure vision does not support external interrupt but just in case
	
	.org $003
	
	SEL MB0
	JMP switch
	
	DIS I			;convenient byte filler
	
;timer interupt vector
;---------------------

;Probably never used but this interrupt is supported by adventure vision

	.org $007
	
	SEL MB0
	JMP switch

;fill remainder of this bank with with following sequence:
	
.equ	b1,	$15 ;dis i		
.equ	b2,	$E5	;sel mb0
.equ	b3,	$E4 ;jmp $7F8
.equ	b4, $F8 ;

	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4
	.db		b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2,b3,b4,b1,b2

;-------------------------------
;The switch to bank 1 routine 
;-------------------------------

;disable interrupts, select external BIOS and jump to $000 in bank 1

;note:
;When the menu button is hold down the code will loop continiously back
; to this switch routine until the menu button is released.
		
	.org	$7F8	;start here to ensure the movp3 a,@a wraps to $000
	
switch:
		
	sel mb0			;memory bank 0
	orl p1,$FF		;port 1 defaults
	orl p2,$FF		;port 2 defaults
	mov a,MENU_BANK	;normally bank 1
	movp3 a,@a		;select bank and wrap to $000 in this bank

;----------------------------------------------
;2nd memory bank 
;----------------------------------------------

	.org $800

;fill remainder of this bank with with following sequence:
	
.equ	b5,	$15 ;dis i		
.equ	b6,	$F5	;sel mb1
.equ	b7,	$E4 ;jmp $FF8
.equ	b8, $F8 ;

	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	.db		b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8,b5,b6,b7,b8
	
	.org $FF8

	dis i		;disable interrupts
	sel mb0		;select bank 0
	orl p1,$FF	;disables BIOS
	orl p2,$FF	;port 2 defaults
	jmp $000	;reset